@@ -326,6 +326,9 @@ vroom_enquo <- function(x) {
 }
 
 vroom_select <- function(x, col_select, id) {
+  # Drop any NULL columns
+  is_null <- vapply(x, is.null, logical(1))
+  x[is_null] <- NULL
   # reorder and rename columns
   if (inherits(col_select, "quosures") || !rlang::quo_is_null(col_select)) {
     if (inherits(col_select, "quosures")) {
@@ -341,7 +344,7 @@ vroom_select <- function(x, col_select, id) {
   x
 }
 
-col_types_standardise <- function(spec, col_names, col_select) {
+col_types_standardise <- function(spec, col_names, col_select, name_repair) {
   type_names <- names(spec$cols)
 
   if (length(spec$cols) == 0) {
@@ -378,6 +381,8 @@ col_types_standardise <- function(spec, col_names, col_select) {
     spec$cols <- spec$cols[col_names]
   }
 
+  names(spec$cols) <- vctrs::vec_as_names(names(spec$cols), repair = name_repair)
+
   if (inherits(col_select, "quosures") || !rlang::quo_is_null(col_select)) {
     if (inherits(col_select, "quosures")) {
       to_keep <- names(spec$cols) %in% tidyselect::vars_select(names(spec$cols), !!!col_select, .strict = FALSE)
